Validator class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
commonValidation(String value, String messageError)
→ String?
-
-
convertToRequiredFormat({required String inputDate, required dynamic inputDateFormat, required dynamic outputDateFormat})
→ String
-
-
dobValidation(String date, String? dateFormat)
→ String?
-
-
emailValidator(String email)
→ String?
-
-
fromDateValidation({required String date, String? dateFormat})
→ String?
-
-
getDateValues(String str)
→ String
-
-
isPastDate(String input, String format)
→ bool
-
-
isPastMonthYear({required String input, String? dateFormat})
→ bool
-
-
isTodayOrLess(String date, String format)
→ bool?
-
-
isValidDate(String format, String input)
→ bool
-
-
isValidDateRange({required String fromDate, required String toDate})
→ bool
-
-
isValidMonthYear(String input)
→ bool
-
-
pickedDate({required String date, required String format})
→ DateTime?
-
-
toDateValidation({required String fromDate, required String toDate, String? dateFormat})
→ String?
-
-
validateConfirmPassword(String value, String password)
→ String?
-
-
validateCurrentPassword(String value)
→ String?
-
-
validateDates(String fromDate, String toDate)
→ bool
-
-
validateEmail(String value)
→ bool
-
-
validateNameWithoutCharacters(String value)
→ bool
-
-
validateNewConfirmPassword(String value, String oldPassword, String newPassword)
→ String?
-
-
validatePassword(String value)
→ String?
-
-
validatePhoneNumber(String? val)
→ String?
-
-
validateSpecialCharacterStructure(String value)
→ bool
-
-
validateStructure(String value)
→ bool
-
-
validateZipCode(String? value)
→ String?
-